@@ -1,4 +1,6 @@
 from .CLUIE import engine
+import view_generator
+import models
 
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 __author__ = 'Mateusz Golembowski'
\ No newline at end of file
